prestoadmin.standalone package
==============================

Submodules
----------

prestoadmin.standalone.config module
------------------------------------

.. automodule:: prestoadmin.standalone.config
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: prestoadmin.standalone
    :members:
    :undoc-members:
    :show-inheritance:
